#
# spec file for package python-oslo.log
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-oslo.log
Version:        6.1.2
Release:        2.2
Summary:        OpenStack log library
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://docs.openstack.org/oslo.log
Source0:        https://files.pythonhosted.org/packages/source/o/oslo.log/oslo.log-6.1.2.tar.gz
BuildRequires:  fdupes
BuildRequires:  openstack-macros
BuildRequires:  python3-eventlet
BuildRequires:  python3-oslo.config >= 5.2.0
BuildRequires:  python3-oslo.context >= 2.21.0
BuildRequires:  python3-oslo.i18n >= 3.20.0
BuildRequires:  python3-oslo.serialization >= 2.25.0
BuildRequires:  python3-oslo.utils >= 3.36.0
BuildRequires:  python3-oslotest
BuildRequires:  python3-pbr >= 3.1.1
BuildRequires:  python3-python-dateutil >= 2.7.0
BuildRequires:  python3-stestr
BuildRequires:  python3-testtools
BuildArch:      noarch

%description
OpenStack logging configuration library provides standardized configuration
for all openstack projects.It also provides custom formatters, handlers and
support for context specific logging (like resource id's etc).

%package -n python3-oslo.log
Summary:        OpenStack log library
Requires:       python3-debtcollector
Requires:       python3-oslo.config >= 5.2.0
Requires:       python3-oslo.context >= 2.21.0
Requires:       python3-oslo.i18n >= 3.20.0
Requires:       python3-oslo.serialization >= 2.25.0
Requires:       python3-oslo.utils >= 3.36.0
Requires:       python3-python-dateutil >= 2.7.0
Requires:       python3-systemd
%if 0%{?suse_version}
Obsoletes:      python2-oslo.log < 4.0.0
%endif

%description -n python3-oslo.log
OpenStack logging configuration library provides standardized configuration
for all openstack projects.It also provides custom formatters, handlers and
support for context specific logging (like resource id's etc).

This package contains the Python 3.x module.

%package -n python-oslo.log-doc
Summary:        Documentation for OpenStack log library
BuildRequires:  python3-Sphinx
BuildRequires:  python3-openstackdocstheme

%description -n python-oslo.log-doc
Documentation for the oslo.log library.

%prep
%autosetup -p1 -n oslo.log-6.1.2
%py_req_cleanup

%build
%{py3_build}

# generate html docs
PYTHONPATH=. PBR_VERSION=6.1.2 %sphinx_build -b html doc/source doc/build/html
rm -rf doc/build/html/.{doctrees,buildinfo}

%install
%{py3_install}
%fdupes %{buildroot}%{python3_sitelib}

%check
# skip test_log_config_append_invalid lp#2023684
%{openstack_stestr_run} --exclude-regex 'test_log_config_append_invalid'

%files -n python3-oslo.log
%license LICENSE
%doc ChangeLog README.rst
%{python3_sitelib}/oslo_log
%{python3_sitelib}/*.egg-info
%{_bindir}/convert-json

%files -n python-oslo.log-doc
%license LICENSE
%doc doc/build/html

%changelog
* Fri Sep 27 2024 Dirk Müller <dmueller@suse.com>
- drop unused monotonic dependency
* Mon Sep  2 2024 cloud-devel@suse.de
- update to version 6.1.2
  - add a missing link to the release note
  - Replace deprecated logging.warn() calls with logging.warning()
  - Remove the usage of the Eventlet debug feature from oslo.log.
  - Mock time.time_ns in test_rfc5424_isotime_format_no_microseconds for py3.13
  - Add option to disable color
  - Revert "Remove the usage of the Eventlet debug feature from oslo.log."
* Tue Jun  4 2024 cloud-devel@suse.de
- update to version 6.0.0
  - reno: Update master for unmaintained/victoria
  - Apply eventlet workaround only once
  - Imported Translations from Zanata
  - Validate rate_limit_except_level by choices
  - Remove unused pyinotify
  - Fix broken reference to rate_limit_except_level
  - Remove old excludes
  - Fix eventlet detection
  - Deprecate watch_log_file
  - Update master for stable/2024.1
  - Remove fallback for old oslo.context
  - Remove implementation for watch_log_file
* Thu May  2 2024 cloud-devel@suse.de
- update to version 5.5.1
  - Fix eventlet detection
  - Bump hacking
  - Update TOX_CONSTRAINTS_FILE for stable/2024.1
  - pre-commit: Bump versions
  - pre-commit: Integrate bandit
  - Update python classifier in setup.cfg
  - Update .gitreview for stable/2024.1
* Thu Dec 28 2023 cloud-devel@suse.de
- update to version 5.4.0
  - Cleanup py27 support
  - Deprecate Windows support
  - Update master for stable/2023.2
  - Imported Translations from Zanata
  - Moves supported python runtimes from version 3.8 to 3.10
  - Revert "Moves supported python runtimes from version 3.8 to 3.10"
  - Catch RuntimeError when loading log config file
  - Bump bandit
  - Update master for stable/2023.1
* Thu Aug 10 2023 Dirk Müller <dmueller@suse.com>
- skip failing tests, run fdupes
* Wed May  3 2023 cloud-devel@suse.de
- update to version 5.2.0
  - Make the eventlet logging fix execution conditional
  - Fix logging in eventlet native threads
  - Update TOX_CONSTRAINTS_FILE for stable/2023.1
  - Revert "Fix logging in eventlet native threads"
  - Update .gitreview for stable/2023.1
  - tox - fix allowlist_external issues
  - Revert "Make the eventlet logging fix execution conditional"
  - Add 'revert bugfix #1983863' release note
* Tue May 24 2022 cloud-devel@suse.de
- update to version 5.0.0
  - Update CI to use unversioned jobs template
  - Drop python3.6/3.7 support in testing runtime
  - Add Yoga to versionutils
  - Use project when logging the user identity
  - Add Zed in versionutils
  - Log Global Request IDs by default
  - Fix formatting of release list
  - [Fix] init global_request_id if not in context
  - Add system scope information to default user identity string
  - Replace deprecated arguments of RequestContext
  - Update python testing classifier
  - Add Python3 yoga unit tests
* Tue Oct 26 2021 cloud-devel@suse.de
- update to version 4.6.0
  - Add Xena to versionutils
  - Remove references to 'sys.version_info'
  - Use TOX_CONSTRAINTS_FILE
  - Update master for stable/victoria
  - setup.cfg: Replace dashes with underscores
  - Drop lower-constraints
  - Adding pre-commit
  - Use py3 as the default runtime for tox
  - Dropping lower constraints testing
  - Move flake8 as a pre-commit local target.
  - Imported Translations from Zanata
  - Ussuri+ is python3 only
  - remove unicode from code
  - Add Python3 wallaby unit tests
  - Fix log_rotate_interval help text formatting
* Fri Oct  9 2020 cloud-devel@suse.de
- update to version 4.4.0
  - Add missing SYSLOG_FACILITY to JournalHandler
  - Add py38 package metadata
  - Align contributing doc with oslo's policy
  - Default facility to None in OSJournalHandler class
  - Imported Translations from Zanata
  - Remove monotonic usage
  - Added uwsgi_name information into fluentFormatter event message
  - Update master for stable/ussuri
  - Bump default tox env from py37 to py38
  - Bump bandit version
  - Remove translation sections from setup.cfg
  - zuul: port the legacy grenade job
  - Add Python3 victoria unit tests
  - Remove the unused coding style modules
  - Add Victoria and Wallaby in versionutils.deprecated
  - Stop to use the __future__ module.
  - Switch to newer openstackdocstheme and reno versions
  - Add release notes links to doc index
* Mon Aug 10 2020 cloud-devel@suse.de
- update to version 4.1.3
  - Update .gitreview for stable/ussuri
  - Add missing SYSLOG_FACILITY to JournalHandler
  - Default facility to None in OSJournalHandler class
  - Update TOX/UPPER_CONSTRAINTS_FILE for stable/ussuri
* Tue May 12 2020 cloud-devel@suse.de
- update to version 4.1.1
  - Serialize complex objects in FluentFormatter
  - Use unittest.mock instead of third party mock
  - Migrate grenade jobs to py3
  - Add Ussuri release to versionutils
  - Stop to build universal wheel
  - remove outdated header
  - Switch to hacking 2.x
  - tox: Trivial cleanup
  - Always use jsonutils.to_primitive 'fallback' parameter
  - Ignore releasenote artifacts files.
  - drop use of six
  - Drop python 2.7 support and testing
  - Add Victoria and Wallaby releases to versionutils
  - tox: Keeping going with docs
  - Switch to official Ussuri jobs
  - Drop use of unittest2
  - Update master for stable/train
* Mon Mar 23 2020 Dirk Mueller <dmueller@suse.com>
- add obsoletes
* Sat Mar 14 2020 Dirk Mueller <dmueller@suse.com>
- switch to python 3.x only builds
* Wed Oct  9 2019 cloud-devel@suse.de
- update to version 3.44.1
  - Use setLevel instead of setting logger.level directly
  - Blacklist sphinx 2.1.0 (autodoc bug)
  - Use raw string for regex
  - Dropping the py35 testing
  - Avoid tox_install.sh for constraints support
  - Add Python 3 Train unit tests
  - Schedule a periodical check of requirements to catch py2.7 issues quickly
  - OpenDev Migration Patch
  - Fix guidelines w.r.t. translation of log messages
  - Replace openstack.org git:// URLs with https://
  - Remove incubator migration docs
  - Replace git.openstack.org URLs with opendev.org URLs
  - Add TRAIN to deprecated releases
  - Cap bandit below 1.6.0 version and update sphinx and limit monotonic.
  - Update master for stable/stein
  - Add 'levelkey' + 'tbkey' params
  - Add logging guidelines based on previous spec
  - Bump the openstackdocstheme extension to 1.20
  - Added cmdline information into fluentFormatter event message
  - Modify the constraints url in tox.
* Mon Apr  8 2019 cloud-devel@suse.de
- update to version 3.42.3
  - Add Windows Event Log handler
  - Imported Translations from Zanata
  - Update mailinglist from dev to discuss
  - Clarify some config options
  - Use template for lower-constraints
  - import zuul job settings from project-config
  - Always build universal wheels
  - Add config options for log rotation
  - Update reno for stable/rocky
  - add python 3.6 unit test job
  - Fix handling of exc_info in OSJournalHandler
  - Default oslo.policy logging to INFO
  - Advancing the protocal of the website to HTTPS in usage.rst.
  - add lib-forward-testing-python3 test job
  - Filter args dict in JSONFormatter
  - Add devstack job with JSONFormatter configured
  - Fix lower-constraints job
  - Follow the new PTI for document build
  - Migrate to stestr
  - rewrite tests to not rely on implementation details of logging module
  - Fix up nits in log rotation change
  - Clean up .gitignore references to personal tools
* Thu Oct 11 2018 cloud-devel@suse.de
- update to version 3.39.2
  - Update UPPER_CONSTRAINTS_FILE for stable/rocky
  - Update .gitreview for stable/rocky
  - import zuul job settings from project-config
  - Filter args dict in JSONFormatter
* Mon Sep  3 2018 cloud-devel@suse.de
- update to version 3.39.0
  - Fix file permissions
  - Update reno for stable/queens
  - Increase sleep time in testsuite to make it more robust
  - Imported Translations from Zanata
  - Add release notes link to README
  - Fix sphinx-docs job
  - Automatically append reset_color to log lines
  - Provide reset_color key on log record
  - Zuul: Remove project name
  - Add ROCKY to deprecated releases
  - Remove stale pip-missing-reqs tox test
  - Add Stein release to versionutils
  - Update links in README
  - Add Rocky release to versionutils._RELEASES
  - Trivial: Update pypi url to new url
  - tox: Group targets and tool configuration together
  - tox: Don't set basepython in testenv
  - set default python to python3
  - fix tox python3 overrides
  - update structured logging tests to prove context id is included
  - Fix Formatter subclasses for Python 3.2+
  - Updated from global requirements
  - add lower-constraints job
- remove 0001-Increase-sleep-time-in-testsuite-to-make-it-more-rob.patch (upstream)
* Tue Mar 20 2018 ro@suse.com
- add 0001-Increase-sleep-time-in-testsuite-to-make-it-more-rob.patch (bsc#1085568)
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Mon Jan 15 2018 cloud-devel@suse.de
- update to version 3.36.0
  - Update the documentation link for doc migration
  - Add release note for use_json option
  - Truncate error_summary if exc_info not explicitly passed
  - Update reno for stable/pike
  - Remove checks for auth_token in JSON-based formatter tests
  - JSONFormatter convert unserializable with repr()
  - Remove setting of version/release from releasenotes
  - Add option to use JSON formatter
  - Imported Translations from Zanata
  - Cleanup test-requirements
  - Allow logging of unhashable exceptions in Python 3
  - Migrate to Zuul v3
  - Zuul: add file extension to playbook path
  - Update the documentation link
  - Updated from global requirements
  - Capture context in its own key for JSON-based formatters
* Mon Aug  7 2017 cloud-devel@suse.de
- update to version 3.30.0
  - only show error_summary for warning and error messages
  - Fix bug in log_method_call decorator
  - refactor error summary logic so it can be reused
  - Add additional info like python-systemd does
  - [Fix gate]Update test requirement
  - Update URLs according to document migration
  - Remove deprecated module loggers
  - Fix devstack colors
  - Update reno for stable/ocata
  - Check reStructuredText documents for common style issues.
  - When record.args is None, it should not give an exception.
  - Trivial: Remove testscenarios from test-requirements.txt
  - Remove 'verbose' option (again)
  - clarify release note for error summary handling
  - Optimize the link address
  - Fix some reST field lists in docstrings
  - make handling of error_summary more flexible
  - formatter: skip ImportError when adding error_summary
  - switch from oslosphinx to openstackdocstheme
  - pbr.version.VersionInfo needs package name (oslo.xyz and not oslo_xyz)
  - Add missing variable html_last_updated_fmt
  - do not add error_summary for debug log messages
  - add error_summary support to JSONFormatter
  - add error_summary support for fluentd formatter
  - tail support, log filtering, executable, and splitlines bug fix
  - Documentation for journal usage
  - improve the documentation for log format strings
  - rearrange content to fit the new standard layout
  - Must not go underneath the context object and access __dict__
  - Remove references to Python 3.4
  - add line number information to fluentd formatter
  - add exception summaries to the main log line
  - Oslo i18n 3.15.2 has broken deps
  - fix test description comment
  - Add log.get_loggers method
  - Remove log translations
  - add an extras dependency for systemd
  - Always create OSSysLogHandler
  - skip built-in exceptions when adding error_summary
  - protect systemd class initialization when syslog is not available
  - Use dict arg values for unicode checks in ContextFormatter
  - Fix syslog module usage breaking Windows compatibility
  - Remove support for py34
  - Systemd native journal support
  - Added is_debug_enabled helper
  - Revert "Remove 'verbose' option (again)"
  - Add oslo_messaging to the list of log levels
  - Updated from global requirements
  - Use Sphinx 1.5 warning-is-error
* Mon Mar 27 2017 cloud-devel@suse.de
- update to version 3.20.1:
  - Must not go underneath the context object and access __dict__
  - Update .gitreview for stable/ocata
- Drop 0001-Must-not-go-underneath-the-context-object-and-access.patch
* Mon Feb 13 2017 tbechtold@suse.com
- Add 0001-Must-not-go-underneath-the-context-object-and-access.patch
* Fri Feb 10 2017 cloud-devel@suse.de
- update to version 3.20.0:
  - Add a json reformatter command
  - Add support for P and Q release names
  - Update reno for stable/newton
  - Avoid converting to unicode if not needed
  - Imported Translations from Zanata
  - standardize release note page ordering
  - Add Constraints support
  - Implement FluentFormatter
  - modify the home-page info with the developer documentation
  - Show team and repo badges on README
  - Default use_stderr to False
  - Use six.wraps instead of functools
  - Fix typos
  - Fix races in unit tests
  - Enable release notes translation
  - Add a filter to rate limit logs
  - Modify use of assertTrue(A in B)
  - Change assertTrue(isinstance()) by optimal assert
  - Replace method attr in vars() to hasattr
  - Updated from global requirements
* Tue Aug 30 2016 tbechtold@suse.com
- update to version 3.16.0
  * Remove discover from test-requirements
  * Fixes unit tests on Windows
  * Fix parameters of assertEqual are misplaced
  * Updated from global requirements
  * Add Python 3.5 classifier and venv
* Wed Aug 10 2016 tbechtold@suse.com
- update to version 3.12.0
  * log: don't create foo.log
  * Improve olso.log test coverage for edge cases
  * log: Introduce _iter_loggers
  * Replace "LOG.exception(_" with "LOG.exception(_LE"
  * Make available to log encoded strings as arguments
  * Revert "Remove 'verbose' option"
  * Imported Translations from Zanata
  * Convert unicode data to utf-8 before calling syslog.syslog()
  * Provide a normal method for deprecation warnings.
  * Fix regression causing the default log level to become WARNING
  * Use new logging specific method for context info
  * Fix typo: 'Olso' to 'Oslo'
  * Reload log_config_append config on SIGHUP
  * Updated from global requirements
  * Remove 'verbose' option
  * Reduce READ_FREQ and TIMEOUT for watch-file
* Tue May 31 2016 tbechtold@suse.com
- update to 3.7.0:
  * Fix example issue
  * Updated from global requirements
  * Allow reload of 'debug' option
  * Imported Translations from Zanata
  * Remove direct dependency on babel
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Remove outdated comment in ContextFormatter
  * Enable log_method_call to work on static method
  * Explicitly exclude tests from bandit scan
  * Improve test code coverage of _options
  * Update reno for stable/mitaka
  * Unit test cleanup and validation improvements
  * Added +2 release names for versionutils
  * Fix broken links in docs usage page
  * Enable bandit in gate
  * Updated from global requirements
- Use renderspec service to update .spec file
* Mon Mar 14 2016 tbechtold@suse.com
- update to 3.2.0:
  * use log.warning instead of log.warn
  * Imported Translations from Zanata
  * Updated from global requirements
  * Remove deprecated use-syslog-rfc-format option
  * Add release note for removed log_format option
  * Updated from global requirements
  * add page for release notes for unreleased versions
  * add a release note about using reno
  * Add reno for release notes management
  * remove pypy from default tox environment list
  * stop making a copy of options discovered by config generator
  * always run coverage report
  * Remove bandit.yaml in favor of defaults
  * Updated from global requirements
  * Fix spell typos
  * set oslo.cache and dogpile to INFO
  * Update translation setup
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Imported Translations from Zanata
  * Updated from global requirements
  * Improve Logging docs with inline examples and context example
  * Revert "Pass environment variables of proxy to tox"
  * Clean up removed hacking rule from [flake8] ignore lists
  * Provide a deprecated_reason for use_syslog_rfc_format
  * Remove deprecated log-format option
  * Improve documentataion of Oslo Log Usage
  * Added public method to getting default log levels
  * Updated from global requirements
  * enable isotime for exceptions
  * assertIsNone(val) instead of assertEqual(None,val)
- Adjust Requires
* Mon Jan  4 2016 dmueller@suse.com
- update to 2.2.0:
  * Set keystoneauth default log level to WARN
  * Format record before passing it to syslog
  * Updated from global requirements
  * Updated from global requirements
  * Remove iso8601 dependency
  * Remove duplicated profiles section from bandit.yaml
  * test_logging_error: build a logger at the test level
  * Cleanup all handlers in _setup_logging_from_conf
  * Drop python 2.6 support
  * Add a 'bandit' target to tox.ini
  * Updated from global requirements
  * Log to sys.stderr to avoid "No handlers could be found..."
  * Remove python 2.6 classifier
  * Remove python 2.6 and cleanup tox.ini
  * Refactor Python 2.6 check to use constant
  * The user_identity format flexibility
  * Updated from global requirements
  * Imported Translations from Zanata
  * Updated from global requirements
  * Allow oslo.log to work on non-linux platforms
* Mon Nov 16 2015 bwiedemann@suse.com
- update to 1.12.0:
  * Fix coverage configuration and execution
  * No need for Oslo Incubator Sync
  * Imported Translations from Zanata
  * Fix unintended assignment of "syslog"
  * Make doc title consistent with readme
  * add documentation with example of an external configuration file
  * add auto-generated docs for config options
  * Update option docs for when log config is used
  * Updated from global requirements
  * Add optional 'fixture' dependencies
  * Change ignore-errors to ignore_errors
  * Fix the home-page value in setup.cfg with openstack.org
  * FastWatchedFileHandler class was added
* Wed Sep  9 2015 tbechtold@suse.com
- update to 1.11.0:
  * Fix poor examples of exception logging
  * Updated from global requirements
- Adjust Requires according to requirements.txt
* Thu Aug 27 2015 tbechtold@suse.com
- update to 1.10.0:
  * Fix package name for PublishErrorsHandler
  * Updated from global requirements
  * Fix duplicate-key pylint issue
  * Maintain old oslo logger names
  * Add Mitaka release to versionutils
  * Update single letter release names to full names
  * Provide a way to register versionutils options
  * Imported Translations from Transifex
  * Updated from global requirements
- Adjust Requires according to requirements.txt
* Wed Aug  5 2015 tbechtold@suse.com
- update to 1.8.0:
  * Set verbose to True and deprecate it
  * Define TRACE logging level
  * Imported Translations from Transifex
  * Updated from global requirements
* Wed Jul 29 2015 tbechtold@suse.com
- Unify spec file. Use fedora compatible files macros
* Tue Jul 28 2015 tbechtold@suse.com
- update to 1.7.0:
  * Imported Translations from Transifex
  * Add more default fancier formatting params
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Do not report deprecations in subclasses
  * Imported Translations from Transifex
  * Updated from global requirements
  * Add tox target to find missing requirements
- update Requires according to requirements.txt
* Sun Jul 19 2015 dmueller@suse.com
- update to 1.6.0:
  * Remove duplication of fatal_deprecations option
  * Imported Translations from Transifex
* Wed Jun 24 2015 tbechtold@suse.com
- update to 1.5.0:
  * Updated from global requirements
  * Switch badges from 'pypip.in' to 'shields.io'
  * Deprecate use-syslog-rfc-format for removal
* Wed Jun 10 2015 tbechtold@suse.com
- update to 1.4.0:
  * just version bump. no other changes
* Tue Jun  2 2015 tbechtold@suse.com
- update to 1.3.0:
  * Do not fail if syslog is not available
  * Use proper deprecation for use-syslog-rfc-format option
  * Replace RFCSysLogHandler by a syslog() based one
  * Make remove_in=0 (no removal) use a better syntax
  * Remove is_compatible from versionutils
  * Add versionutils options to list_opts
  * Add versionutils to API documentation
  * Advertise support for Python3.4 / Remove support for Python 3.3
  * Updated from global requirements
  * Updated from global requirements
  * Remove run_cross_tests.sh
  * Deprecate WritableLogger - used for eventlet logging
  * Log deprecation message when catching deprecated exceptions
  * Change misleading TRACE to ERROR
  * Uncap library requirements for liberty
  * Provide an API to let tempest control the log file
  * fix pep8 errors
  * Add pypi download + version badges
  * Update to latest hacking
  * Add link to Logging Guidelines
  * move versionutils into place
  * Add liberty release name to versionutils
  * Expose opts entry point for version_utils
  * Switch from oslo.config to oslo_config
  * Remove oslo.log code and clean up versionutils API
  * Remove code that moved to oslo.i18n
  * Enhance versionutils.deprecated to work with classes
  * Add Kilo release name to versionutils
  * Allow deprecated decorator to specify no plan for removal
  * Add JUNO as a target to versionutils module
  * pep8: fixed multiple violations
  * Use oslotest instead of common test module
  * Use hacking import_exceptions for gettextutils._
  * fixed typos
  * Fix violations of H302:import only modules
  * Adds decorator to deprecate functions and methods
  * Remove vim header
  * Add `versionutils` for version compatibility checks
  * Default to True for use-syslog-rfc-format
  * Updated from global requirements
  * Restore automatic unicode conversion
  * Add migration notes
- Adjust Requires according to requirements.txt
* Wed Apr 22 2015 tbechtold@suse.com
- Add missing BuildRequires and enable testsuite
* Wed Apr 22 2015 tbechtold@suse.com
- Remove python-discover from BuildRequires. We no longer care
  about python < 2.7 versions.
* Tue Mar 10 2015 tbechtold@suse.com
- update to 1.0.0:
  * Updated from global requirements
  * Pickup instance from log format record
  * Make use_syslog=True log to syslog via /dev/log
- update Requires according to requirements.txt
* Tue Feb 24 2015 tbechtold@suse.com
- update to version 0.3.0:
  * Updated from global requirements
- Update Requires
* Thu Feb  5 2015 tbechtold@suse.com
- update to version 0.2.0:
  * Expose fixtures through oslo_log.fixture
  * Add fixture to let tests change log levels
  * Rename logging fixture module
  * Update comment to match implementation
  * fix link to bug tracker in readme
  * Updated from global requirements
- Update Requires
* Fri Jan 23 2015 tbechtold@suse.com
- Adjust Requires versions
* Fri Jan 23 2015 tbechtold@suse.com
- Initial packaging
